<?php
/**
* @package  EasyBlog
* @copyright Copyright (C) 2010 - 2019 Stack Ideas Sdn Bhd. All rights reserved.
* @license  GNU/GPL, see LICENSE.php
* EasyBlog is free software. This version may have been modified pursuant
* to the GNU General Public License, and as distributed it includes or
* is derivative of works licensed under the GNU General Public License or
* other free or open source software licenses.
* See COPYRIGHT.php for copyright notices and details.
*/
defined('_JEXEC') or die('Unauthorized Access');

require_once(JPATH_ADMINISTRATOR . '/components/com_easyblog/includes/easyblog.php');

class BlogControllerBlog extends SocialAppsController
{
	/**
	 * Process post cover upload from the story form
	 *
	 * @since	5.3
	 * @access	public
	 */
	public function upload()
	{
		// Retrieve the file data from the upload process
		$file = $this->input->files->get('blog_cover');

		// Return an error if there do not have any temporary file path
		if (!isset($file['tmp_name']) || empty($file['tmp_name'])) {
			return $this->ajax->reject(JText::_('APP_USER_BLOG_INVALID_FILE'));
		}

		// Set hidden input file name
		$options = array('name' => 'blog_cover');

		// Trying to get uploaded file
		$uploader = ES::uploader($options);
		$file = $uploader->getFile(null, '');

		// Return an error if there was an error getting uploaded file
		if ($file instanceof SocialException) {
			return $this->ajax->reject($file->message);
		}

		// Load image lib
		$image = ES::image();

		// Load the image file 
		$image->load($file['tmp_name'], $file['name']);

		// Ensure the image is valid
		if (!$image->isValid()) {
			return $this->ajax->reject(JText::_('APP_USER_BLOG_INVALID_FILE'));
		}

		// Load up media manager library
		$media = EB::mediamanager();

		// Get uri from the form
		$key = $this->input->getRaw('placeKey');

		// decode the placeKey value
		$uri = $media->getUri($key);

		// Check if the file is really allowed to be uploaded to the site.
		$state = EB::image()->canUploadFile($file);

		if ($state instanceof Exception) {
			return $this->ajax->reject($state->getMessage());
		}

		// MM should check if the user really has access to upload to the target folder
		$allowed = $media->hasAccess($uri);

		if ($allowed instanceof Exception) {
			return $this->ajax->reject($allowed->getMessage());
		}

		// Check the image name is it got contain space, if yes need to replace to '-'
		$fileName = $file['name'];
		$file['name'] = str_replace(' ', '-', $fileName);

		// Upload the file now
		$adapter = $media->getAdapter($uri);
		$file = $adapter->upload($file, $uri);

		// Throw an error if the upload fails
		if ($file instanceof Exception) {
			return $this->ajax->reject($file->getMessage());
		}

		$response = new stdClass();
		$response->media = $media->getInfo($file->uri, true);

		return $this->ajax->resolve($response);
	}
}
