EasySocial.module("story/blog", function($) {

var module = this;

EasySocial.Controller("Story.Blog", {
	defaultOptions: {
		"{title}" : "[data-blog-title]",
		"{content}" : "[data-blog-content]",
		"{category}": "[data-story-blog-category]",

		"{blogCoverFrame}": "[data-blog-frame]",
		"{removeCoverButton}": "[data-blog-cover-remove]",
		"{removeCoverWrapper}": "[data-blog-cover-remove-wrapper]",
		"{blogCoverUploadButton}": "[data-blog-cover-upload-button]",
		"{blogCover}": "[data-blog-cover]",
		"{blogCoverRemoveButtonWrapper}": "[data-blog-remove-cover-wrapper]",
		"{blogCoverKey}": "[data-blog-cover-key]",
		"{blogCoverURI}": "[data-blog-cover-uri]"
	}

}, function(self, opts) { return {

	resetForm: function() {

		// reset all the field after save
		self.title().val('');
		self.content().val('');
		self.blogCoverURI().val('');
		self.setBlogCover('');
		self.removeCoverWrapper().addClass('t-hidden');
		self.blogCoverUploadButton().removeClass('t-hidden');
	},

	"{story} save": function(element, event, save) {

		if (save.currentPanel != 'blog') {
			return;
		}
		
		self.savePost = save.addTask('savePost');

		self.save(save);
	},

	save: function(save) {

		var savePost = self.savePost;

		if (!savePost) {
			return;
		}
			
		var title = self.title().val();

		if (!title) {
			self.clearMessage();
			save.reject('<?php echo $errorTitle; ?>');
			return false;
		}

		var content = self.content().val();

		if (!content) {
			self.clearMessage();
			save.reject('<?php echo $errorContent; ?>');
			return false;
		}

		var uri = self.blogCoverURI().val();

		var data = {"categoryId" : self.category().val(), "title" : title, "content" : content, "uri" : uri};

		self.resetForm();

		save.addData(self, data);

		savePost.resolve();

		delete self.savePost;

	},

	'{blogCover} change' : function(el, event) {

		if ($.isEmpty(el.val())) {
			return;
		}

		// Retrieve the user place folder storage id
		var placeKey = self.blogCoverKey().val();		

		// Show the spinning icon
		self.blogCoverFrame().addClass('is-loading');

		// hide the upload button
		self.blogCoverUploadButton().addClass('t-hidden');

		EasySocial.ajax('apps/user/blog/controllers/blog/upload', {
			files: el,
			placeKey: placeKey
		}, {
			type: 'iframe'
		}).done(function(result) {

			// Remove the spinning icon 
			self.blogCoverFrame().removeClass('is-loading');

			// set the user post cover uri
			self.blogCoverURI().val(result.media.uri);

			// show the remove cover image icon
			self.removeCoverWrapper().removeClass('t-hidden');

			// set the image on the preview area
			self.setBlogCover(result.media.meta.preview);

		}).fail(function(msg) {

			// Remove the spinning icon
			self.blogCoverFrame().removeClass('is-loading');

			// show the upload button
			self.blogCoverUploadButton().removeClass('t-hidden');

			// clear the message if there got any message shown up
			self.clearMessage();

			// populate the error message
			self.setMessage(msg);
		});
	},

	setBlogCover: function(url, position) {

		// set the image URL to preview after upload
		self.blogCoverFrame()
			.css({
				backgroundImage: $.cssUrl(url)
			});

		self.clearMessage();
	},

	"{removeCoverButton} click": function(el) {

		// hide the remove cover image icon
		self.removeCoverWrapper().addClass('t-hidden');

		// show the upload button
		self.blogCoverUploadButton().removeClass('t-hidden');

		// reset the blog cover URI value from the hidden input
		self.blogCoverURI().val('');

		// clear the image url from the image preview section
		self.setBlogCover('');
	}

}});

// Resolve module
module.resolve();

});

EasySocial.require()
.script("story/blog")
.done(function($) {
	var plugin = story.addPlugin("blog");
});